Represents an array that can be nested to an arbitrary depth.
Useful for recursive data and flat-map operations.
The leaf value type.
const flat: NestedArray<number> = [1, 2, 3];const deep: NestedArray<number> = [1, [2, [3, 4]], 5]; Copy
const flat: NestedArray<number> = [1, 2, 3];const deep: NestedArray<number> = [1, [2, [3, 4]], 5];
Represents an array that can be nested to an arbitrary depth.
Useful for recursive data and flat-map operations.